@@ -227,7 +227,7 @@ class CmeClient(AbstractClient):
 
 
     def DeleteMaterial(self, request):
-        """根据素材 Id 删除素材。
+        """根据媒体 Id 删除媒体。
 
         :param request: Request instance for DeleteMaterial.
         :type request: :class:`tencentcloud.cme.v20191029.models.DeleteMaterialRequest`
@@ -425,7 +425,7 @@ class CmeClient(AbstractClient):
 
 
     def DescribeMaterials(self, request):
-        """根据素材 Id 批量获取素材详情。
+        """根据媒体 Id 批量获取媒体详情。
 
         :param request: Request instance for DescribeMaterials.
         :type request: :class:`tencentcloud.cme.v20191029.models.DescribeMaterialsRequest`
@@ -539,7 +539,7 @@ class CmeClient(AbstractClient):
 
 
     def DescribeSharedSpace(self, request):
-        """获取共享空间。当实体A对实体B授权某资源以后，实体B的共享空间就会增加实体A。
+        """获取共享空间。当个人或团队A对个人或团队B授权某资源以后，个人或团队B的共享空间就会增加个人或团队A。
 
         :param request: Request instance for DescribeSharedSpace.
         :type request: :class:`tencentcloud.cme.v20191029.models.DescribeSharedSpaceRequest`
@@ -765,7 +765,7 @@ class CmeClient(AbstractClient):
 
 
     def FlattenListMedia(self, request):
-        """平铺分类路径下及其子分类下的所有素材。
+        """平铺分类路径下及其子分类下的所有媒体基础信息。
 
         :param request: Request instance for FlattenListMedia.
         :type request: :class:`tencentcloud.cme.v20191029.models.FlattenListMediaRequest`
@@ -823,7 +823,7 @@ class CmeClient(AbstractClient):
 
 
     def GrantResourceAuthorization(self, request):
-        """资源所属实体对目标实体授予目标资源的相应权限。
+        """资源归属者对目标个人或团队授予目标资源的相应权限。
 
         :param request: Request instance for GrantResourceAuthorization.
         :type request: :class:`tencentcloud.cme.v20191029.models.GrantResourceAuthorizationRequest`
@@ -907,7 +907,7 @@ class CmeClient(AbstractClient):
 
 
     def ListMedia(self, request):
-        """浏览当前分类路径下的资源，包括素材和子分类。
+        """浏览当前分类路径下的资源，包括媒体文件和子分类，返回媒资基础信息和分类信息。
 
         :param request: Request instance for ListMedia.
         :type request: :class:`tencentcloud.cme.v20191029.models.ListMediaRequest`
@@ -935,7 +935,7 @@ class CmeClient(AbstractClient):
 
 
     def ModifyMaterial(self, request):
-        """修改素材信息，支持修改素材名称、分类路径、标签等信息。
+        """修改媒体信息，支持修改媒体名称、分类路径、标签等信息。
 
         :param request: Request instance for ModifyMaterial.
         :type request: :class:`tencentcloud.cme.v20191029.models.ModifyMaterialRequest`
@@ -1049,7 +1049,9 @@ class CmeClient(AbstractClient):
 
     def MoveClass(self, request):
         """移动某一个分类到另外一个分类下，也可用于分类重命名。
-        <li>如果 SourceClassPath = /素材/视频/NBA，DestinationClassPath = /素材/视频/篮球，当 DestinationClassPath 不存在时候，操作结果为重命名 ClassPath，如果 DestinationClassPath 存在时候，操作结果为产生新目录 /素材/视频/篮球/NBA。</li>
+        如果 SourceClassPath = /素材/视频/NBA，DestinationClassPath = /素材/视频/篮球
+        <li>当 DestinationClassPath 不存在时候，操作结果为重命名 ClassPath；</li>
+        <li>当 DestinationClassPath 存在时候，操作结果为产生新目录 /素材/视频/篮球/NBA</li>
 
         :param request: Request instance for MoveClass.
         :type request: :class:`tencentcloud.cme.v20191029.models.MoveClassRequest`
@@ -1076,6 +1078,39 @@ class CmeClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def MoveResource(self, request):
+        """移动资源，支持跨个人或团队移动媒体以及分类。如果填写了Operator，则需要校验用户对媒体和分类资源的访问以及写权限。
+        <li>当原始资源为媒体时，该接口效果为将该媒体移动到目标分类下面；</li>
+        <li>当原始资源为分类时，该接口效果为将原始分类移动到目标分类或者是重命名。</li>
+         如果 SourceResource.Resource.Id = /素材/视频/NBA，DestinationResource.Resource.Id= /素材/视频/篮球
+        <li>当 DestinationResource.Resource.Id 不存在时候且原始资源与目标资源归属相同，操作结果为重命名原始分类；</li>
+        <li>当 DestinationResource.Resource.Id 存在时候，操作结果为产生新目录 /素材/视频/篮球/NBA</li>
+
+        :param request: Request instance for MoveResource.
+        :type request: :class:`tencentcloud.cme.v20191029.models.MoveResourceRequest`
+        :rtype: :class:`tencentcloud.cme.v20191029.models.MoveResourceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("MoveResource", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.MoveResourceResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def RevokeResourceAuthorization(self, request):
         """资源所属实体对目标实体回收目标资源的相应权限，若原本没有相应权限则不产生变更。
 
@@ -1105,7 +1140,7 @@ class CmeClient(AbstractClient):
 
 
     def SearchMaterial(self, request):
-        """根据检索条件搜索素材，返回素材的基本信息。
+        """根据检索条件搜索媒体，返回媒体的基本信息。
 
         :param request: Request instance for SearchMaterial.
         :type request: :class:`tencentcloud.cme.v20191029.models.SearchMaterialRequest`
